declare let PlotConfig: {
    isPlotting: boolean;
    startTimeIndex: number;
};
declare let LayoutMelodyContourPlot: {
    title: string;
    plot_bgcolor: string;
    paper_bgcolor: string;
    autosize: boolean;
    width: number;
    height: number;
    xaxis: {
        type: string;
        title: string;
    };
    yaxis: {
        autorange: boolean;
        range: number[];
        type: string;
        title: string;
    };
};
declare let LayoutChromaPlot: {
    title: string;
    plot_bgcolor: string;
    paper_bgcolor: string;
    autosize: boolean;
    width: number;
    height: number;
    xaxis: {
        autorange: boolean;
        time: string;
        title: string;
    };
    yaxis: {
        title: string;
        range: number[];
    };
};
declare var LayoutSpectrogramPlot: {
    title: string;
    plot_bgcolor: string;
    paper_bgcolor: string;
    autosize: boolean;
    width: number;
    height: number;
    xaxis: {
        title: string;
        autorange: boolean;
        time: string;
    };
    yaxis: {
        title: string;
        range: null;
        type: string;
    };
};
/**
 * @class Base class for essentia plot
 */
declare class EssentiaPlot {
    Plotly: any;
    options: any;
    isPlotting: boolean;
    startTimeIndex: number;
    /**
     *Creates an instance of EssentiaPlot.
    * @param {*} Plotly
    * @param {*} [options=CONFIG]
    * @memberof EssentiaPlot
    */
    constructor(Plotly: any, options?: any);
    /**
     * Return evenly spaced numbers over a specified interval
     * Returns num evenly spaced samples, calculated over the interval [start, stop].
     * @param {*} start The starting value of the sequence.
     * @param {*} stop The end value of the sequence
     * @param {*} num Number of samples to generate. Must be non-negative
     * @returns
     * @memberof EssentiaPlot
     */
    makeLinearSpace(start: any, stop: any, num: any): any[];
}
/**
 * @class PlotMelodyContour
 * @extends {EssentiaPlot}
 */
declare class PlotMelodyContour extends EssentiaPlot {
    Plotly: any;
    divId: string;
    plotLayout: any;
    /**
     *Creates an instance of PlotMelodyContour.
     * @param {string} divId
     * @param {*} [plotLayout=LayoutMelodyContour]
     * @memberof PlotMelodyContour
     */
    constructor(Plotly: any, divId: string, plotLayout?: any);
    /**
     * Create the melody contour plot given inputs using Plotly.js
     * @method
     * @param {Float32Array} featureArray
     * @param {string} plotTitle
     * @param {number} audioFrameSize
     * @param {number} audioSampleRate
     * @memberof PlotMelodyContour
     */
    create(featureArray: Float32Array, plotTitle: string, audioFrameSize: any, audioSampleRate: any): void;
    /**
     * Remove the existing Plotly plot
     * @method
     * @memberof PlotMelodyContour
     */
    destroy(): void;
}
/**
 * @class PlotHeatmap
 * @extends {EssentiaPlot}
 */
declare class PlotHeatmap extends EssentiaPlot {
    Plotly: any;
    divId: string;
    plotType: string;
    plotLayout: any;
    yAxis: any;
    /**
     *Creates an instance of PlotHeatmap.
    * @param {*} Plotly
    * @param {string} divId
    * @param {string} [plotType='chroma']
    * @param {*} [plotLayout=LayoutChromaHeatmap]
    * @memberof PlotHeatmap
    */
    constructor(Plotly: any, divId: string, plotType: string, plotLayout: any);
    /**
     * Create Plotly.js heatmap plot with given input array and type
     * @param {Array} featureArray
     * @param {string} plotTitle
     * @param {*} audioFrameSize
     * @param {*} audioSampleRate
     * @param {string} [colorscale='Jet']
     * @memberof PlotChromaHeatmap
     */
    create(featureArray: any, plotTitle: string, audioFrameSize: any, audioSampleRate: any, colorscale?: string): void;
    /**
     * Remove the existing Plotly plot
     * @method
     * @memberof PlotHeatmap
     */
    destroy(): void;
}
export { EssentiaPlot, PlotMelodyContour, PlotHeatmap, LayoutMelodyContourPlot, LayoutChromaPlot, LayoutSpectrogramPlot, PlotConfig };
